<?php

namespace Drupal\murmurations;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form for the module
 */
class SettingsForm extends ConfigFormBase {

  const NODE_TYPES = ["co-op", "social enterprise", "community", "ecovillage", "alliance", "network", "federation", "farm", "school"];


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'murmurations_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('murmurations.settings');

    $form['mission'] = [
      '#title' => $this->t('Mission'),
      '#description' => $this->t("The mission, purpose, or objective of your project or organisation"),
      '#required' => FALSE,
      '#type' => 'textarea',
      '#element_validate' => [[$this, 'max1000']],
      '#weight' => 1,
      '#default_value' => $config->get('mission'),
    ];

    $node_types = array_combine(SELF::NODE_TYPES, SELF::NODE_TYPES);
    array_walk($node_types, function (&$val){
      $val= ucfirst($val);
    });

    $form['node_types'] = [
      '#title' => $this->t('Organisation or project types'),
      '#description' => $this->t("Examples: co-op, farm, school, community, NGO, etc"),
      '#required' => TRUE,
      '#type' => 'select',
      '#multiple' => TRUE,
      '#options' => $node_types,
      '#weight' => 2,
      '#default_value' => $config->get('node_types'),
    ];
    $form['location'] = [
      '#title' => $this->t('Location'),
      '#description' => $this->t("The name of a place, e.g. Inverness, Scotland."),
      '#required' => FALSE,
      '#type' => 'textfield',
      '#maxlength' => 1000,
      '#element_validate' => [[$this, 'max1000']],
      '#weight' => 3,
      '#default_value' => $config->get('location'),
    ];
    $form['lat'] = [
      '#title' => $this->t('Latitude'),
      '#type' => 'textfield',
      '#required' => 'TRUE',
      '#weight' => 4,
      '#default_value' => $config->get('lat'),
    ];
    $form['lon'] = [
      '#title' => $this->t('Longitude'),
      '#type' => 'textfield',
      '#required' => 'TRUE',
      '#weight' => 5,
      '#default_value' => $config->get('lon'),
    ];
    $form['networks'] = [
      '#title' => $this->t('Networks'),
      '#description' => $this->t("What networks does this organisation or project belong to?"),
      '#required' => FALSE,
      '#type' => 'textfield',
      '#weight' => 6,
      '#default_value' => $config->get('networks'),
    ];
    $form['allies'] = [
      '#title' => $this->t('Allied projects'),
      '#description' => $this->t("Enter the website addresses of allied organisations or projects (comma separated)"),
      '#required' => FALSE,
      '#type' => 'textfield',
      '#weight' => 7,
      '#default_value' => $config->get('allies'),
    ];
    $form['tags'] = [
      '#title' => $this->t('Tags'),
      '#description' => $this->t("The most common tags you use to describe your sector or topic (comma separated)"),
      '#required' => TRUE,
      '#type' => 'textfield',
      '#weight' => 7,
      '#default_value' => $config->get('tags'),
    ];
    $form['feed'] = [
      '#title' => $this->t('RSS feed URL'),
      '#description' => $this->t('If you publish news or content using the RSS format.'),
      '#required' => FALSE,
      '#type' => 'textfield',
      '#weight' => 8,
      '#default_value' => $config->get('feed'),
    ];

    return parent::buildForm($form, $form_state);;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('murmurations.settings')
      ->set('mission', $form_state->getValue('mission'))
      ->set('node_types', array_filter($form_state->getValue('node_types')))
      ->set('location', $form_state->getValue('location'))
      ->set('lat', $form_state->getValue('lat'))
      ->set('lon', $form_state->getValue('lon'))
      ->set('networks', $form_state->getValue('networks'))
      ->set('allies', $form_state->getValue('allies'))
      ->set('tags', $form_state->getValue('tags'))
      ->set('feed', $form_state->getValue('feed'))
      ->save();
    parent::submitForm($form, $form_state);
    murmurations_submit_to_index();
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['murmurations.settings'];
  }

  /**
   * Element validation callback.
   *
   * @param type $element
   * @param FormStateInterface $form_state
   */
  public function max1000(&$element, FormStateInterface $form_state) {
    if (strlen($element['#value']) > 1000) {
      $form_state->setError($element, $this->t('Max 1000 chars'));
    }
  }


}
